@@ -196,8 +196,10 @@ class T1xT2BET(FSLCommand):
     input_spec = T1xT2BETInputSpec
     output_spec = T1xT2BETOutputSpec
 
-    package_directory = os.path.dirname(os.path.abspath(__file__))
-    _cmd = 'bash {}/../bash/T1xT2BET.sh'.format(package_directory)
+    path_to_current_dir = os.path.dirname(os.path.abspath(__file__))
+    package_directory = os.path.dirname(path_to_current_dir)
+
+    _cmd = 'bash {}/bash/T1xT2BET.sh'.format(package_directory)
 
     def _list_outputs(self):
 
@@ -256,9 +258,10 @@ class AtlasBREXInputSpec(CommandLineInputSpec):
 
     import os
 
-    package_directory = os.path.dirname(os.path.abspath(__file__))
+    path_to_current_dir = os.path.dirname(os.path.abspath(__file__))
+    package_directory = os.path.dirname(path_to_current_dir)
 
-    script_atlas_BREX = File('{}/../bash/atlasBREX.sh'.format(
+    script_atlas_BREX = File('{}/bash/atlasBREX.sh'.format(
             package_directory), usedefault=True,
         exists=True,
         desc='atlasBREX script',
@@ -397,4 +400,11 @@ class AtlasBREX(CommandLine):
 
         path, fname, ext = split_f(self.inputs.t1_restored_file)
         outputs["brain_file"] = os.path.abspath(fname + '_brain' + ext)
+
         return outputs
+
+
+if __name__ == '__main__':
+    ab = AtlasBREX()
+
+    print(ab.cmdline)
