@@ -6,8 +6,122 @@ import os
 import json
 
 from nipype.interfaces.fsl.base import FSLCommand, FSLCommandInputSpec
+
 from nipype.interfaces.base import (CommandLine, CommandLineInputSpec,
-                                    TraitedSpec, File, traits)
+                                    TraitedSpec, File, traits, Str)
+
+from nipype.interfaces.afni.base import AFNICommandBase, AFNICommandOutputSpec
+
+
+# Refit # rewritten from nipype to include -origin
+# would be best to have a PR on nipype directly
+class RefitInputSpec(CommandLineInputSpec):
+    in_file = File(
+        desc="input file to 3drefit",
+        argstr="%s",
+        position=-1,
+        mandatory=True,
+        exists=True,
+        copyfile=True,
+    )
+    deoblique = traits.Bool(
+        desc="replace current transformation matrix with cardinal matrix",
+        argstr="-deoblique",
+    )
+    xorigin = Str(desc="x distance for edge voxeloffset", argstr="-xorigin %s")
+    yorigin = Str(desc="y distance for edge voxeloffset", argstr="-yorigin %s")
+    zorigin = Str(desc="z distance for edge voxeloffset", argstr="-zorigin %s")
+    duporigin_file = File(
+        argstr="-duporigin %s",
+        exists=True,
+        desc="Copies the xorigin, yorigin, and zorigin values from the header "
+        "of the given dataset",
+    )
+    xdel = traits.Float(desc="new x voxel dimension in mm", argstr="-xdel %f")
+    ydel = traits.Float(desc="new y voxel dimension in mm", argstr="-ydel %f")
+    zdel = traits.Float(desc="new z voxel dimension in mm", argstr="-zdel %f")
+    xyzscale = traits.Float(
+        desc="Scale the size of the dataset voxels by the given factor",
+        argstr="-xyzscale %f",
+    )
+
+    origin = traits.Str(
+        argstr="-origin %s",
+        desc="Defines the orientation e.g RSA, LPS, etc.")
+
+    space = traits.Enum(
+        "TLRC",
+        "MNI",
+        "ORIG",
+        argstr="-space %s",
+        desc="Associates the dataset with a specific template type, e.g. "
+        "TLRC, MNI, ORIG",
+    )
+    atrcopy = traits.Tuple(
+        File(exists=True),
+        traits.Str(),
+        argstr="-atrcopy %s %s",
+        desc="Copy AFNI header attribute from the given file into the header "
+        "of the dataset(s) being modified. For more information on AFNI "
+        "header attributes, see documentation file README.attributes. "
+        "More than one '-atrcopy' option can be used. For AFNI "
+        "advanced users only. Do NOT use -atrcopy or -atrstring with "
+        "other modification options. See also -copyaux.",
+    )
+    atrstring = traits.Tuple(
+        traits.Str(),
+        traits.Str(),
+        argstr="-atrstring %s %s",
+        desc="Copy the last given string into the dataset(s) being modified, "
+        "giving it the attribute name given by the last string."
+        "To be safe, the last string should be in quotes.",
+    )
+    atrfloat = traits.Tuple(
+        traits.Str(),
+        traits.Str(),
+        argstr="-atrfloat %s %s",
+        desc="Create or modify floating point attributes. "
+        "The input values may be specified as a single string in quotes "
+        "or as a 1D filename or string, example "
+        "'1 0.2 0 0 -0.2 1 0 0 0 0 1 0' or "
+        "flipZ.1D or '1D:1,0.2,2@0,-0.2,1,2@0,2@0,1,0'",
+    )
+    atrint = traits.Tuple(
+        traits.Str(),
+        traits.Str(),
+        argstr="-atrint %s %s",
+        desc="Create or modify integer attributes. "
+        "The input values may be specified as a single string in quotes "
+        "or as a 1D filename or string, example "
+        "'1 0 0 0 0 1 0 0 0 0 1 0' or "
+        "flipZ.1D or '1D:1,0,2@0,-0,1,2@0,2@0,1,0'",
+    )
+    saveatr = traits.Bool(
+        argstr="-saveatr",
+        desc="(default) Copy the attributes that are known to AFNI into "
+        "the dset->dblk structure thereby forcing changes to known "
+        "attributes to be present in the output. This option only makes "
+        "sense with -atrcopy.",
+    )
+    nosaveatr = traits.Bool(argstr="-nosaveatr", desc="Opposite of -saveatr")
+
+
+class Refit(AFNICommandBase):
+    """Changes some of the information inside a 3D dataset's header
+
+    For complete details, see the `3drefit Documentation.
+    <https://afni.nimh.nih.gov/pub/dist/doc/program_help/3drefit.html>`_
+
+    """
+
+    _cmd = "3drefit"
+    input_spec = RefitInputSpec
+    output_spec = AFNICommandOutputSpec
+
+    def _list_outputs(self):
+        outputs = self.output_spec().get()
+        outputs["out_file"] = os.path.abspath(self.inputs.in_file)
+        return outputs
 
 
 # FslOrient
@@ -159,7 +273,7 @@ class CropVolume(CommandLine):
 
 ###############################################################################
 # Equivalent of flirt_average in FSL
-def average_align(list_img):
+def average_align(list_img, reorient=False):
 
     import os
     import nibabel as nib
@@ -168,8 +282,6 @@ def average_align(list_img):
     from nipype.utils.filemanip import split_filename as split_f
     import nipype.interfaces.fsl as fsl
 
-    print("average_align:", list_img)
-
     if isinstance(list_img, list):
 
         assert len(list_img) > 0, "Error, list should have at least one file"
@@ -182,8 +294,17 @@ def average_align(list_img):
             img_0 = nib.load(list_img[0])
             path, fname, ext = split_f(list_img[0])
 
-            list_data = [img_0.get_data()]
+            data_0 = img_0.get_fdata()
+
+            data_0_shape = data_0.shape
+            list_data = [data_0]
+
             for i, img in enumerate(list_img[1:]):
+                data_orig_shape = nib.load(img).get_fdata().shape
+                if data_orig_shape != data_0_shape:
+                    print(f"**** Warning , original image shape \
+                          {data_orig_shape} \
+                          have a different shape than ref {data_0_shape}")
 
                 print("running flirt on {}".format(img))
                 flirt = fsl.FLIRT(dof=6)
@@ -194,11 +315,21 @@ def average_align(list_img):
                 out_file = flirt.run().outputs.out_file
                 print(out_file)
 
-                data = nib.load(out_file).get_data()
+                data = nib.load(out_file).get_fdata()
+                assert data.shape == data_0_shape, \
+                    f"**** Error, flirt results {out_file} \
+                    have a different shape {data.shape} \
+                    than ref {data_0_shape}"
+
                 list_data.append(data)
 
             avg_data = np.mean(np.array(list_data), axis=0)
-            print(avg_data.shape)
+
+            assert data_0_shape == avg_data.shape, \
+                f"Error with average shape {avg_data.shape} != {data_0_shape}"
+
+            # after casting type
+            avg_data = avg_data.astype(np.int16)
 
             av_img_file = os.path.abspath("avg_" + fname + ext)
             nib.save(nib.Nifti1Image(avg_data, header=img_0.header,
@@ -206,9 +337,10 @@ def average_align(list_img):
                      av_img_file)
 
     else:
-        assert os.path.exists(list_img)
         av_img_file = list_img
 
+    assert os.path.exists(av_img_file)
+
     return av_img_file
 
 
@@ -265,6 +397,7 @@ def padding_cropped_img(cropped_img_file, orig_img_file, indiv_crop):
     data_cropped = cropped_img.get_data()
 
     print("Cropped img shape:", data_cropped.shape)
+    print("data_cropped.dtype: {}".format(data_cropped.dtype))
 
     if len(data_orig.shape) == 3 and len(data_cropped.shape) == 4:
         print("Padding with 3D params on a 4D image")
@@ -274,6 +407,11 @@ def padding_cropped_img(cropped_img_file, orig_img_file, indiv_crop):
 
         padded_img_data = np.zeros(shape=padded_img_data_shape,
                                    dtype=data_cropped.dtype)
+
+        if not np.issubdtype(data_cropped.dtype, np.integer):
+            print("Converting to NaN")
+            padded_img_data[:] = np.nan
+
         print("Broscasted padded img shape:", padded_img_data_shape)
 
         for t in range(data_cropped.shape[3]):
@@ -281,13 +419,22 @@ def padding_cropped_img(cropped_img_file, orig_img_file, indiv_crop):
                 data_cropped[:, :, :, t]
 
     else:
+        print("Padding with 3D params on a 3D image")
 
         padded_img_data = np.zeros(shape=data_orig.shape,
                                    dtype=data_cropped.dtype)
+
         print("Padded img shape:", padded_img_data.shape)
+        print("Padded_img_data.dtype: {}".format(padded_img_data.dtype))
+
+        if not np.issubdtype(data_cropped.dtype, np.integer):
+            print("Converting to NaN")
+            padded_img_data[:] = np.nan
 
         padded_img_data[xmin:xmax, ymin:ymax, zmin:zmax] = data_cropped
 
+        print("After Adding values")
+
     # saving padded image
     fpath, fname, ext = split_f(cropped_img_file)
     padded_img_file = os.path.abspath(fname + "_padded" + ext)
@@ -298,21 +445,6 @@ def padding_cropped_img(cropped_img_file, orig_img_file, indiv_crop):
     return padded_img_file
 
 
-def reg_aladin_dirty(reference, in_file):
-
-    import os
-
-    cwd = os.path.abspath("")
-    os.chdir(cwd)
-    out_file = os.path.abspath("outputResult.nii")
-    cmd = "reg_aladin -flo {} -ref {} -res {}".format(
-        in_file, reference, out_file)
-    os.system(cmd)
-
-    assert os.path.exists(out_file)
-    return out_file
-
-
 if __name__ == '__main__':
 
     data_path = "/hpc/meca/data/Macaques/Macaque_hiphop/results/ucdavis"
