@@ -7,13 +7,18 @@ import nipype.interfaces.afni as afni
 import nipype.interfaces.freesurfer as fs
 
 import macapype.nodes.register as reg
-from macapype.nodes.surface import Meshify, split_LR_mask
+
+from macapype.nodes.surface import (Meshify, split_LR_mask,
+                                    wrap_nii2mesh,
+                                    wrap_afni_IsoSurface, merge_tissues,
+                                    keep_gcc)
+
 from macapype.utils.utils_nodes import parse_key, NodeParams
 
 
 def _create_split_hemi_pipe(params, params_template, name="split_hemi_pipe"):
-
-    """Description: Split segmentated tissus according hemisheres after \
+    """
+    Description: Split segmentated tissus according hemisheres after \
     removal of cortical structure
 
     Processing steps:
@@ -628,3 +633,131 @@ def create_nii_to_mesh_fs_pipe(params, name="nii_to_mesh_fs_pipe"):
                                 smooth_tess_rh, 'in_file')
 
     return nii_to_mesh_fs_pipe
+
+
+###############################################################################
+def create_nii2mesh_brain_pipe(params={},
+                               name="nii2mesh_brain_pipe"):
+
+    # creating pipeline
+    nii2mesh_brain_pipe = pe.Workflow(name=name)
+
+    # creating inputnode
+    inputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["segmented_file"]),
+        name='inputnode')
+
+    # merge_brain_tissues
+    merge_brain_tissues = NodeParams(
+        interface=niu.Function(input_names=["dseg_file", "keep_indexes"],
+                               output_names=["mask_file"],
+                               function=merge_tissues),
+        params=parse_key(params, "merge_brain_tissues"),
+        name="keep_GCC_brain")
+
+    nii2mesh_brain_pipe.connect(inputnode, 'segmented_file',
+                                merge_brain_tissues, 'dseg_file')
+
+    # bin_mask
+    bin_mask = pe.Node(interface=fsl.UnaryMaths(), name="bin_mask")
+    bin_mask.inputs.operation = "bin"
+
+    nii2mesh_brain_pipe.connect(merge_brain_tissues,
+                                'mask_file', bin_mask, 'in_file')
+
+    # keep_gcc_bin_mask
+    keep_gcc_bin_mask = pe.Node(
+        interface=niu.Function(input_names=["nii_file"],
+                               output_names=["gcc_nii_file"],
+                               function=keep_gcc),
+        name="keep_gcc_bin_mask")
+
+    nii2mesh_brain_pipe.connect(bin_mask, "out_file",
+                                keep_gcc_bin_mask, "nii_file")
+
+    # wmgm2mesh
+    wmgm2mesh = pe.Node(
+        interface=niu.Function(input_names=["nii_file"],
+                               output_names=["stl_file"],
+                               function=wrap_nii2mesh),
+        name="wmgm2mesh")
+
+    nii2mesh_brain_pipe.connect(keep_gcc_bin_mask, 'gcc_nii_file',
+                                wmgm2mesh, "nii_file")
+
+    # outputnode
+    outputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["wmgm_stl", "wmgm_nii"]),
+        name='outputnode')
+
+    nii2mesh_brain_pipe.connect(keep_gcc_bin_mask, 'gcc_nii_file',
+                                outputnode, "wmgm_nii")
+    nii2mesh_brain_pipe.connect(wmgm2mesh, 'stl_file', outputnode, "wmgm_stl")
+
+    return nii2mesh_brain_pipe
+
+
+def create_IsoSurface_brain_pipe(params={},
+                                 name="IsoSurface_brain_pipe"):
+
+    # creating pipeline
+    IsoSurface_brain_pipe = pe.Workflow(name=name)
+
+    # creating inputnode
+    inputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["segmented_file"]),
+        name='inputnode')
+
+    # merge_brain_tissues
+    merge_brain_tissues = NodeParams(
+        interface=niu.Function(input_names=["dseg_file", "keep_indexes"],
+                               output_names=["mask_file"],
+                               function=merge_tissues),
+        params=parse_key(params, "merge_brain_tissues"),
+        name="keep_GCC_brain")
+
+    IsoSurface_brain_pipe.connect(inputnode, 'segmented_file',
+                                  merge_brain_tissues, 'dseg_file')
+
+    # bin mask
+    bin_mask = pe.Node(interface=fsl.UnaryMaths(), name="bin_mask")
+    bin_mask.inputs.operation = "bin"
+
+    IsoSurface_brain_pipe.connect(merge_brain_tissues,
+                                  'mask_file', bin_mask, 'in_file')
+
+    # keep_gcc_bin_mask
+    keep_gcc_bin_mask = pe.Node(
+        interface=niu.Function(input_names=["nii_file"],
+                               output_names=["gcc_nii_file"],
+                               function=keep_gcc),
+        name="keep_gcc_bin_mask")
+
+    IsoSurface_brain_pipe.connect(bin_mask, "out_file",
+                                  keep_gcc_bin_mask, "nii_file")
+
+    # wmgm2mesh
+    wmgm2mesh = pe.Node(
+        interface=niu.Function(input_names=["nii_file"],
+                               output_names=["stl_file"],
+                               function=wrap_afni_IsoSurface),
+        name="wmgm2mesh")
+
+    IsoSurface_brain_pipe.connect(keep_gcc_bin_mask, 'gcc_nii_file',
+                                  wmgm2mesh, "nii_file")
+
+    # outputnode
+    outputnode = pe.Node(
+        niu.IdentityInterface(
+            fields=["wmgm_stl", "wmgm_nii"]),
+        name='outputnode')
+
+    IsoSurface_brain_pipe.connect(keep_gcc_bin_mask, 'gcc_nii_file',
+                                  outputnode, "wmgm_nii")
+    IsoSurface_brain_pipe.connect(wmgm2mesh, 'stl_file',
+                                  outputnode, "wmgm_stl")
+
+    return IsoSurface_brain_pipe
